@@ -1,4 +1,4 @@
-# Copyright 2015 Google Inc. All Rights Reserved.
+# Copyright 2015-2016 Google Inc. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -32,6 +32,7 @@ from yapf.yapflib import format_token
 from yapf.yapflib import pytree_utils
 from yapf.yapflib import split_penalty
 from yapf.yapflib import style
+from yapf.yapflib import unwrapped_line
 
 _COMPOUND_STMTS = frozenset({'for', 'while', 'if', 'elif', 'with', 'except',
                              'def', 'class'})
@@ -83,7 +84,7 @@ class FormatDecisionState(object):
 
   def Clone(self):
     new = copy.copy(self)
-    new.stack = copy.deepcopy(self.stack)
+    new.stack = [copy.copy(state) for state in self.stack]
     return new
 
   def __eq__(self, other):
@@ -94,9 +95,9 @@ class FormatDecisionState(object):
             self.column == other.column and
             self.paren_level == other.paren_level and
             self.start_of_line_level == other.start_of_line_level and
-            self.lowest_level_on_line == other.lowest_level_on_line and (
-                self.ignore_stack_for_comparison or
-                other.ignore_stack_for_comparison or self.stack == other.stack))
+            self.lowest_level_on_line == other.lowest_level_on_line and
+            (self.ignore_stack_for_comparison or
+             other.ignore_stack_for_comparison or self.stack == other.stack))
 
   def __ne__(self, other):
     return not self == other
@@ -128,12 +129,27 @@ class FormatDecisionState(object):
     if current.must_break_before:
       return True
 
-    if (self.stack[-1].split_before_closing_bracket and
-        # FIXME(morbo): Use the 'matching_bracket' instead of this.
-        # FIXME(morbo): Don't forget about tuples!
-        current.value in ']}'):
-      # Split if we need to split before the closing bracket and the next
-      # token is a closing bracket.
+    if (previous and (style.Get('DEDENT_CLOSING_BRACKETS') or
+                      style.Get('SPLIT_BEFORE_FIRST_ARGUMENT'))):
+      bracket = current if current.ClosesScope() else previous
+      if format_token.Subtype.SUBSCRIPT_BRACKET not in bracket.subtypes:
+        if bracket.OpensScope():
+          if (unwrapped_line.IsSurroundedByBrackets(bracket) or
+              not _IsLastScopeInLine(bracket)):
+            last_token = bracket.matching_bracket
+          else:
+            last_token = _LastTokenInLine(bracket.matching_bracket)
+
+          length = last_token.total_length - bracket.total_length
+          if length + self.column >= column_limit:
+            self.stack[-1].split_before_closing_bracket = True
+            return True
+
+        elif style.Get('DEDENT_CLOSING_BRACKETS') and current.ClosesScope():
+          return self.stack[-1].split_before_closing_bracket
+
+    if self.stack[-1].split_before_closing_bracket and current.value in '}]':
+      # Split if we need to split before the closing bracket.
       return current.node_split_penalty != split_penalty.UNBREAKABLE
 
     if not previous:
@@ -156,12 +172,22 @@ class FormatDecisionState(object):
           current.value not in '=,)'):
         opening = _GetOpeningParen(current)
         if opening:
-          arglist_length = (
-              opening.matching_bracket.total_length - opening.total_length +
-              self.column)
+          arglist_length = (opening.matching_bracket.total_length -
+                            opening.total_length + self.column)
           return arglist_length > column_limit
 
-    if previous.value in '{[' and current.lineno != previous.lineno:
+    if style.Get('SPLIT_ARGUMENTS_WHEN_COMMA_TERMINATED'):
+      # Split before arguments in a function call or definition if the
+      # arguments are terminated by a comma.
+      opening = _GetOpeningParen(current)
+      if opening and opening.previous_token and opening.previous_token.is_name:
+        if previous.value in '(,':
+          if opening.matching_bracket.previous_token.value == ',':
+            return True
+
+    if (previous.value in '{[' and current.lineno != previous.lineno and
+        format_token.Subtype.SUBSCRIPT_BRACKET not in previous.subtypes):
+      # Retain the split after the container opening.
       return True
 
     if (previous.value == ':' and _IsDictionaryValue(current) and
@@ -171,6 +197,7 @@ class FormatDecisionState(object):
 
     if (format_token.Subtype.COMP_FOR in current.subtypes and
         format_token.Subtype.COMP_FOR not in previous.subtypes):
+      # Split at the beginning of a list comprehension.
       length = _GetLengthOfSubtype(current, format_token.Subtype.COMP_FOR,
                                    format_token.Subtype.COMP_IF)
       if length + self.column > column_limit:
@@ -178,13 +205,14 @@ class FormatDecisionState(object):
 
     if (format_token.Subtype.COMP_IF in current.subtypes and
         format_token.Subtype.COMP_IF not in previous.subtypes):
+      # Split at the beginning of an if expression.
       length = _GetLengthOfSubtype(current, format_token.Subtype.COMP_IF)
       if length + self.column > column_limit:
         return True
 
     previous_previous_token = previous.previous_token
-    if (previous_previous_token and previous_previous_token.name == 'NAME' and
-        not previous_previous_token.is_keyword and previous.value == '('):
+    if (current.is_name and previous_previous_token and
+        previous_previous_token.is_name and previous.value == '('):
       sibling = previous.node.next_sibling
       if pytree_utils.NodeName(sibling) == 'arglist':
         arglist = previous.node.next_sibling
@@ -204,8 +232,9 @@ class FormatDecisionState(object):
             # up the formatting.
             return True
 
-    if (style.Get('SPLIT_BEFORE_BITWISE_OPERATOR') and
-        current.value in '&|' and previous.lineno < current.lineno):
+    if (style.Get('SPLIT_BEFORE_BITWISE_OPERATOR') and current.value in '&|' and
+        previous.lineno < current.lineno):
+      # Retain the split before a bitwise operator.
       return True
 
     if (current.is_comment and
@@ -309,9 +338,9 @@ class FormatDecisionState(object):
         not current.is_binary_op and not previous.OpensScope()):
       self.stack[-1].split_before_parameter = True
 
-    if (previous.OpensScope() or
-        (previous.is_comment and previous.previous_token is not None and
-         previous.previous_token.OpensScope())):
+    if (previous.OpensScope() or (previous.is_comment and
+                                  previous.previous_token is not None and
+                                  previous.previous_token.OpensScope())):
       self.stack[-1].closing_scope_indent = max(
           0, self.stack[-1].indent - style.Get('CONTINUATION_INDENT_WIDTH'))
       self.stack[-1].split_before_closing_bracket = True
@@ -319,18 +348,21 @@ class FormatDecisionState(object):
     # Calculate the split penalty.
     penalty = current.split_penalty
 
+    if must_split:
+      # Don't penalize for a must split.
+      return penalty
+
     if previous.is_pseudo_paren and previous.value == '(':
       # Small penalty for splitting after a pseudo paren.
       penalty += 50
 
-    # Add a penalty for each increasing newline we add.
-    last = self.stack[-1]
-    penalty += (style.Get('SPLIT_PENALTY_FOR_ADDED_LINE_SPLIT') *
-                last.num_line_splits)
+    # Add a penalty for each increasing newline we add, but don't penalize for
+    # splitting before an if-expression or list comprehension.
     if not must_split and current.value not in {'if', 'for'}:
-      # Don't penalize for a must split or for splitting before an
-      # if-expression or list comprehension.
+      last = self.stack[-1]
       last.num_line_splits += 1
+      penalty += (style.Get('SPLIT_PENALTY_FOR_ADDED_LINE_SPLIT') *
+                  last.num_line_splits)
 
     return penalty + 10
 
@@ -347,9 +379,9 @@ class FormatDecisionState(object):
       return top_of_stack.indent if self.paren_level else self.first_indent
 
     if current.ClosesScope():
-      if (previous.OpensScope() or
-          (previous.is_comment and previous.previous_token is not None and
-           previous.previous_token.OpensScope())):
+      if (previous.OpensScope() or (previous.is_comment and
+                                    previous.previous_token is not None and
+                                    previous.previous_token.OpensScope())):
         return max(0,
                    top_of_stack.indent - style.Get('CONTINUATION_INDENT_WIDTH'))
       return top_of_stack.closing_scope_indent
@@ -364,7 +396,8 @@ class FormatDecisionState(object):
           return top_of_stack.indent
 
     if (self.line.first.value in _COMPOUND_STMTS and
-        not style.Get('DEDENT_CLOSING_BRACKETS')):
+        (not style.Get('DEDENT_CLOSING_BRACKETS') or
+         style.Get('SPLIT_BEFORE_FIRST_ARGUMENT'))):
       token_indent = (len(self.line.first.whitespace_prefix.split('\n')[-1]) +
                       style.Get('INDENT_WIDTH'))
       if token_indent == top_of_stack.indent:
@@ -394,7 +427,6 @@ class FormatDecisionState(object):
       new_indent = style.Get('CONTINUATION_INDENT_WIDTH') + last.last_space
 
       self.stack.append(_ParenState(new_indent, self.stack[-1].last_space))
-      self.stack[-1].break_before_paremeter = False
       self.paren_level += 1
 
     # If we encounter a closing bracket, we can remove a level from our
@@ -456,13 +488,31 @@ def _GetLengthOfSubtype(token, subtype, exclude=None):
 
 def _GetOpeningParen(current):
   previous = current
+  if previous and previous.matching_bracket:
+    return previous.matching_bracket
   while previous is not None and previous.matching_bracket is None:
     previous = previous.previous_token
+    if not previous:
+      break
     if previous.ClosesScope():
       previous = previous.matching_bracket.previous_token
   return previous
 
 
+def _LastTokenInLine(current):
+  while not current.is_comment and current.next_token:
+    current = current.next_token
+  return current
+
+
+def _IsLastScopeInLine(current):
+  while current:
+    current = current.next_token
+    if current and current.OpensScope():
+      return False
+  return True
+
+
 class _ParenState(object):
   """Maintains the state of the bracket enclosures.
 
