@@ -1,4 +1,4 @@
-# Copyright 2015 Google Inc. All Rights Reserved.
+# Copyright 2015-2016 Google Inc. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -38,16 +38,17 @@ class Subtype(object):
   UNARY_OPERATOR = 1
   BINARY_OPERATOR = 2
   SUBSCRIPT_COLON = 3
-  DEFAULT_OR_NAMED_ASSIGN = 4
-  VARARGS_STAR = 5
-  KWARGS_STAR_STAR = 6
-  ASSIGN_OPERATOR = 7
-  DICTIONARY_KEY = 8
-  DICTIONARY_VALUE = 9
-  DICT_SET_GENERATOR = 10
-  COMP_FOR = 11
-  COMP_IF = 12
-  DEFAULT_OR_NAMED_ASSIGN_ARG_LIST = 13
+  SUBSCRIPT_BRACKET = 4
+  DEFAULT_OR_NAMED_ASSIGN = 5
+  VARARGS_STAR = 6
+  KWARGS_STAR_STAR = 7
+  ASSIGN_OPERATOR = 8
+  DICTIONARY_KEY = 9
+  DICTIONARY_VALUE = 10
+  DICT_SET_GENERATOR = 11
+  COMP_FOR = 12
+  COMP_IF = 13
+  DEFAULT_OR_NAMED_ASSIGN_ARG_LIST = 14
 
 
 class FormatToken(object):
@@ -196,6 +197,12 @@ class FormatToken(object):
     return pytree_utils.GetNodeAnnotation(self._node,
                                           pytree_utils.Annotation.NEWLINES)
 
+  @property
+  def must_split(self):
+    """Return true if the token requires a split before it."""
+    return pytree_utils.GetNodeAnnotation(self._node,
+                                          pytree_utils.Annotation.MUST_SPLIT)
+
   @property
   def column(self):
     """The original column number of the node in the source."""
