@@ -1,4 +1,4 @@
-# Copyright 2015 Google Inc. All Rights Reserved.
+# Copyright 2015-2016 Google Inc. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -76,6 +76,7 @@ _GRAMMAR_FOR_PY3 = pygram.python_grammar_no_print_statement.copy()
 del _GRAMMAR_FOR_PY3.keywords['exec']
 
 _GRAMMAR_FOR_PY2 = pygram.python_grammar.copy()
+del _GRAMMAR_FOR_PY2.keywords['nonlocal']
 
 
 def ParseCodeToTree(code):
@@ -281,12 +282,10 @@ def DumpNodeToString(node):
 def _PytreeNodeRepr(node):
   """Like pytree.Node.__repr__, but names instead of numbers for tokens."""
   if isinstance(node, pytree.Node):
-    return '%s(%s, %r)' % (node.__class__.__name__,
-                           NodeName(node),
+    return '%s(%s, %r)' % (node.__class__.__name__, NodeName(node),
                            [_PytreeNodeRepr(c) for c in node.children])
   if isinstance(node, pytree.Leaf):
-    return '%s(%s, %r)' % (node.__class__.__name__,
-                           NodeName(node), node.value)
+    return '%s(%s, %r)' % (node.__class__.__name__, NodeName(node), node.value)
   # Throw an exception if it's not an expected type:
   assert isinstance(node, (pytree.Node, pytree.Leaf)), type(node)
 
