@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2015 Google Inc. All Rights Reserved.
+# Copyright 2015-2016 Google Inc. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -816,7 +816,7 @@ class CommandLineTest(unittest.TestCase):
             [
                 'do',
 
-                'that',
+                'that'
             ]
         """)
     expected_formatted_code = textwrap.dedent(u"""\
@@ -832,7 +832,7 @@ class CommandLineTest(unittest.TestCase):
         def still_horrible():
             oh_god()
             why_would_you()
-            ['do', 'that', ]
+            ['do', 'that']
         """)
     self.assertYapfReformats(unformatted_code,
                              expected_formatted_code,
@@ -854,9 +854,9 @@ class CommandLineTest(unittest.TestCase):
         class A(object):
             def aaaaaaaaaaaaa(self):
                 c = bbbbbbbbb.ccccccccc('challenge', 0, 1, 10)
-                self.assertEqual(
-                    ('ddddddddddddddddddddddddd', 'eeeeeeeeeeeeeeeeeeeeeeeee.%s' %
-                     c.ffffffffffff), gggggggggggg.hhhhhhhhh(c, c.ffffffffffff))
+                self.assertEqual(('ddddddddddddddddddddddddd',
+                                  'eeeeeeeeeeeeeeeeeeeeeeeee.%s' % c.ffffffffffff),
+                                 gggggggggggg.hhhhhhhhh(c, c.ffffffffffff))
                 iiiii = jjjjjjjjjjjjjj.iiiii
         """)
     self.assertYapfReformats(unformatted_code,
@@ -879,9 +879,9 @@ class CommandLineTest(unittest.TestCase):
         class A(object):
             def aaaaaaaaaaaaa(self):
                 c = bbbbbbbbb.ccccccccc('challenge', 0, 1, 10)
-                self.assertEqual(
-                    ('ddddddddddddddddddddddddd', 'eeeeeeeeeeeeeeeeeeeeeeeee.%s' %
-                     c.ffffffffffff), gggggggggggg.hhhhhhhhh(c, c.ffffffffffff))
+                self.assertEqual(('ddddddddddddddddddddddddd',
+                                  'eeeeeeeeeeeeeeeeeeeeeeeee.%s' % c.ffffffffffff),
+                                 gggggggggggg.hhhhhhhhh(c, c.ffffffffffff))
                 iiiii = jjjjjjjjjjjjjj.iiiii
         """)
     self.assertYapfReformats(unformatted_code,
@@ -974,8 +974,8 @@ second_argument_makes_the_line_too_long):
         """)
     self.assertYapfReformats(unformatted_code,
                              expected_formatted_code,
-                             extra_options=['--lines', '1-1',
-                                            '--style', 'chromium'])
+                             extra_options=['--lines', '1-1', '--style',
+                                            'chromium'])
 
   def testMultilineCommentFormattingDisabled(self):
     unformatted_code = textwrap.dedent(u"""\
@@ -1008,8 +1008,8 @@ second_argument_makes_the_line_too_long):
         """)
     self.assertYapfReformats(unformatted_code,
                              expected_formatted_code,
-                             extra_options=['--lines', '1-1',
-                                            '--style', 'chromium'])
+                             extra_options=['--lines', '1-1', '--style',
+                                            'chromium'])
 
   def testTrailingCommentsWithDisabledFormatting(self):
     unformatted_code = textwrap.dedent(u"""\
@@ -1028,8 +1028,8 @@ second_argument_makes_the_line_too_long):
         """)
     self.assertYapfReformats(unformatted_code,
                              expected_formatted_code,
-                             extra_options=['--lines', '1-1',
-                                            '--style', 'chromium'])
+                             extra_options=['--lines', '1-1', '--style',
+                                            'chromium'])
 
 
 class BadInputTest(unittest.TestCase):
